% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/match_label.R
\name{BayCount_match_lable}
\alias{BayCount_match_lable}
\title{Match labels}
\usage{
BayCount_match_lable(BayCount_model, simu_truth, B = 1000, nmc = 1000)
}
\arguments{
\item{BayCount_model}{a list of BayCount MCMC results}

\item{simu_truth}{a list of simulation true parameters and observed count matrix}

\item{B}{number of burn-in iterations in the MCMC}

\item{nmc}{number of post-burn-in iterations in the MCMC}
}
\value{
BayCount_model with the correct labeling order of subclones according to the simulation truth
}
\description{
Match labelsbetween inference of BayCount and simulation truth
}
\examples{
# Let us consider a medium scale synthetic example.
# In particular, we consider the synthetic_data dataset
# This dataset is used in Section 3.1 in the manuscript
# loading required packages
library(Rcpp)
library(combinat)
library(RColorBrewer)
library(gplots)
# Let us initialize the hyperparameters
hyper=NULL
hyper$eta = 0.1
hyper$a0 = 0.01
hyper$b0 = 0.01
hyper$e0 = 1
hyper$f0 = 1
hyper$g0 = 1
hyper$h0 = 1
hyper$u0 = hyper$v0 = 100
B = 1000
nmc = 1000
K_range = 1:10
sample_ind = (B + 1):(B + nmc)
###############################################################
# Run the BayCount model with known K                         #
###############################################################
attach(synthetic_data)
G = dim(Y)[1]
S = dim(Y)[2]
K = dim(Phi)[2]
Init = list(Phi = matrix(1/G, nrow = G, ncol = K), Theta = matrix(15, nrow = K, ncol = S))
BayCount_inference = BayCount_MCMC(Y, Init, hyper, B, nmc, K, Print_Iter = TRUE)
BayCount_inference = BayCount_match_lable(BayCount_inference, simu_truth = synthetic_data)
Phi_hat = apply(BayCount_inference$Phi[, , sample_ind], c(1, 2), mean)
Theta_hat_norm = apply(BayCount_inference$Theta_norm[, , sample_ind], c(1, 2), mean)
detach(synthetic_data)

}
